import { User } from '../models/user.ts';
import type { App } from '@kevisual/router';

/**
 * 添加auth中间件, 用于验证token
 * @param app
 */
export const addAuth = (app: App) => {
  app
    .route({
      path: 'auth',
      id: 'auth',
    })
    .define(async (ctx) => {
      const token = ctx.query.token;
      if (!token) {
        app.throw(401, 'Token is required');
      }
      const user = await User.getOauthUser(token);
      if (!user) {
        app.throw(401, 'Token is invalid');
      }
      if (ctx.state) {
        ctx.state.tokenUser = user;
      } else {
        ctx.state = {
          tokenUser: user,
        };
      }
    })
    .addTo(app);

  app
    .route({
      path: 'auth',
      key: 'can',
      id: 'auth-can',
    })
    .define(async (ctx) => {
      if (ctx.query?.token) {
        const token = ctx.query.token;
        const user = await User.getOauthUser(token);
        if (ctx.state) {
          ctx.state.tokenUser = user;
        } else {
          ctx.state = {
            tokenUser: user,
          };
        }
      }
    })
    .addTo(app);
};
